/*
  Point Shooter Cyborg Mouse
 Design and Code by Zack Freedman, 2013
 http://zackfreedman.com/projects/pointshooter
 http://voidstarlab.com/diy
 
 Designed for Teensy 3.0
 
 Download i2c_t3 at http://forum.pjrc.com/archive/index.php/t-21680.html
 
 Any original content contained within this source is placed in the public domain.
 WiiChuck.h is public domain, please read its credits too.
 */

#include <math.h>
#include <i2c_t3.h>
#include "WiiChuck.h"

WiiChuck chuck = WiiChuck();

boolean hasOrigin = false;
int pitchOrigin = 0;
int rollOrigin = 0;

void setup() 
{
  pinMode(5, INPUT_PULLUP);
  pinMode(6, INPUT_PULLUP);
  pinMode(7, INPUT_PULLUP);

  //Serial.begin(115200);
  `
  chuck.begin();
  chuck.update();
  
  delay(3000); // So you can program it before it starts acting like a mouse
  
  Mouse.begin();
}


void loop() {
  delay(10);

  if (digitalRead(5) == LOW)
  {
    chuck.update(); 

    if (!hasOrigin)
    {
      for (int i = 0; i < 5; i++)
      {
        pitchOrigin += chuck.readPitch();

        rollOrigin += chuck.readRoll();

        delay(1);
        chuck.update();
      }

      pitchOrigin /= 5;
      rollOrigin /= 5;

/*
      Serial.print("New pitch origin: ");
      Serial.println(pitchOrigin);

      Serial.print("New roll origin: ");
      Serial.println(rollOrigin);
*/

      hasOrigin = true;
    }

    int y = constrain((pitchOrigin - chuck.readPitch()) * 6, -100, 100);
    int x = constrain((chuck.readRoll() - rollOrigin) * 4, -100, 100);

    float magnitude = sqrt(pow(x, 2) + pow(y, 2));
    float direction = atan2(y, x);

    double scale = 0.1; // Increase to make cursor move faster
    int division = 70; // Increase to reduce acceleration effect

    magnitude = scale * (magnitude * magnitude / division);

    x = magnitude * cos(direction);
    y = magnitude * sin(direction);

    /*
    Serial.print(x);
     Serial.print(", ");  
     Serial.println(y);
     */

    Mouse.move(x, y, 0);
  }
  else
  {
    pitchOrigin = 0;
    rollOrigin = 0;

    hasOrigin = false;
  }
  
  if (digitalRead(6) == LOW) Mouse.press(MOUSE_LEFT);
   else Mouse.release(MOUSE_LEFT);
   
   if (digitalRead(7) == LOW) Mouse.press(MOUSE_RIGHT);
   else Mouse.release(MOUSE_RIGHT);
   
}





